==> qt6-base-6.0.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6Core/Qt6CoreConfigExtras.cmake <==
if(NOT DEFINED QT_DEFAULT_MAJOR_VERSION)
    set(QT_DEFAULT_MAJOR_VERSION 6)
endif()

# include(\"${CMAKE_CURRENT_LIST_DIR}/Qt5CoreConfigExtrasMkspecDir.cmake\")
#
# foreach(_dir ${_qt5_corelib_extra_includes})
#     _qt5_Core_check_file_exists(${_dir})
# endforeach()

# list(APPEND Qt5Core_INCLUDE_DIRS ${_qt5_corelib_extra_includes})
# set_property(TARGET Qt6::Core APPEND PROPERTY INTERFACE_INCLUDE_DIRECTORIES ${_qt5_corelib_extra_includes})
# set(_qt5_corelib_extra_includes)

if (NOT QT_NO_CREATE_TARGETS)
    set_property(TARGET Qt6::Core PROPERTY INTERFACE_QT_MAJOR_VERSION 6)
    set_property(TARGET Qt6::Core PROPERTY INTERFACE_QT_COORD_TYPE double)
    set_property(TARGET Qt6::Core APPEND PROPERTY
      COMPATIBLE_INTERFACE_STRING QT_MAJOR_VERSION QT_COORD_TYPE
    )
    if (NOT "" STREQUAL "")
        set_property(TARGET Qt6::Core APPEND PROPERTY INTERFACE_COMPILE_DEFINITIONS QT_NAMESPACE=)
    endif()
    set_property(TARGET Qt6::Core APPEND PROPERTY INTERFACE_COMPILE_DEFINITIONS $<$<NOT:$<CONFIG:Debug>>:QT_NO_DEBUG>)
    set_property(TARGET Qt6::Core PROPERTY INTERFACE_COMPILE_FEATURES cxx_decltype)
endif()

set(CMAKE_AUTOMOC_MACRO_NAMES "Q_OBJECT" "Q_GADGET" "Q_NAMESPACE" "Q_NAMESPACE_EXPORT")

# install layout information, following what qmake -query provides
get_filename_component(QT6_INSTALL_PREFIX ${CMAKE_CURRENT_LIST_DIR}/../../../ ABSOLUTE)
set(QT6_INSTALL_ARCHDATA "lib/qt6")
set(QT6_INSTALL_BINS "lib/qt6/bin")
set(QT6_INSTALL_CONFIGURATION "etc/xdg")
set(QT6_INSTALL_DATA "share/qt6")
set(QT6_INSTALL_DOCS "share/doc/qt6")
set(QT6_INSTALL_EXAMPLES "share/doc/qt6/examples")
set(QT6_INSTALL_HEADERS "include/qt6")
set(QT6_INSTALL_LIBS "lib")
set(QT6_INSTALL_LIBEXECS "lib/qt6/libexec")
set(QT6_INSTALL_PLUGINS "lib/qt6/plugins")
set(QT6_INSTALL_QML "lib/qt6/qml")
set(QT6_INSTALL_TESTS "tests")
set(QT6_INSTALL_TRANSLATIONS "share/qt6/translations")
set(QT6_IS_SHARED_LIBS_BUILD "ON")

get_filename_component(_Qt6CoreConfigDir ${CMAKE_CURRENT_LIST_FILE} PATH)
set(_Qt6CTestMacros "${_Qt6CoreConfigDir}/Qt6CTestMacros.cmake")


set(QT_VISIBILITY_AVAILABLE TRUE)

if(ANDROID_PLATFORM)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6AndroidMacros.cmake")
endif()

==> qt6-base-6.0.3-2-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6Core/Qt6CoreConfigExtras.cmake <==
if(NOT DEFINED QT_DEFAULT_MAJOR_VERSION)
    set(QT_DEFAULT_MAJOR_VERSION 6)
endif()

# include(\"${CMAKE_CURRENT_LIST_DIR}/Qt5CoreConfigExtrasMkspecDir.cmake\")
#
# foreach(_dir ${_qt5_corelib_extra_includes})
#     _qt5_Core_check_file_exists(${_dir})
# endforeach()

# list(APPEND Qt5Core_INCLUDE_DIRS ${_qt5_corelib_extra_includes})
# set_property(TARGET Qt6::Core APPEND PROPERTY INTERFACE_INCLUDE_DIRECTORIES ${_qt5_corelib_extra_includes})
# set(_qt5_corelib_extra_includes)

if (NOT QT_NO_CREATE_TARGETS)
    set_property(TARGET Qt6::Core PROPERTY INTERFACE_QT_MAJOR_VERSION 6)
    set_property(TARGET Qt6::Core PROPERTY INTERFACE_QT_COORD_TYPE double)
    set_property(TARGET Qt6::Core APPEND PROPERTY
      COMPATIBLE_INTERFACE_STRING QT_MAJOR_VERSION QT_COORD_TYPE
    )
    if (NOT "" STREQUAL "")
        set_property(TARGET Qt6::Core APPEND PROPERTY INTERFACE_COMPILE_DEFINITIONS QT_NAMESPACE=)
    endif()
    set_property(TARGET Qt6::Core APPEND PROPERTY INTERFACE_COMPILE_DEFINITIONS $<$<NOT:$<CONFIG:Debug>>:QT_NO_DEBUG>)
    set_property(TARGET Qt6::Core PROPERTY INTERFACE_COMPILE_FEATURES cxx_decltype)
endif()

set(CMAKE_AUTOMOC_MACRO_NAMES "Q_OBJECT" "Q_GADGET" "Q_NAMESPACE" "Q_NAMESPACE_EXPORT")

# install layout information, following what qmake -query provides
get_filename_component(QT6_INSTALL_PREFIX ${CMAKE_CURRENT_LIST_DIR}/../../../ ABSOLUTE)
set(QT6_INSTALL_ARCHDATA "lib/qt6")
set(QT6_INSTALL_BINS "lib/qt6/bin")
set(QT6_INSTALL_CONFIGURATION "etc/xdg")
set(QT6_INSTALL_DATA "share/qt6")
set(QT6_INSTALL_DOCS "share/doc/qt6")
set(QT6_INSTALL_EXAMPLES "share/doc/qt6/examples")
set(QT6_INSTALL_HEADERS "include/qt6")
set(QT6_INSTALL_LIBS "lib")
set(QT6_INSTALL_LIBEXECS "lib/qt6")
set(QT6_INSTALL_PLUGINS "lib/qt6/plugins")
set(QT6_INSTALL_QML "lib/qt6/qml")
set(QT6_INSTALL_TESTS "tests")
set(QT6_INSTALL_TRANSLATIONS "share/qt6/translations")
set(QT6_IS_SHARED_LIBS_BUILD "ON")

get_filename_component(_Qt6CoreConfigDir ${CMAKE_CURRENT_LIST_FILE} PATH)
set(_Qt6CTestMacros "${_Qt6CoreConfigDir}/Qt6CTestMacros.cmake")


set(QT_VISIBILITY_AVAILABLE TRUE)

if(ANDROID_PLATFORM)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6AndroidMacros.cmake")
endif()
